BLubb Howto
===========

:Author:    $Author: seletz $
:Date:      $Date: 2008-01-17 15:46:54 +0100 (Do, 17 Jan 2008) $
:Revision:  $Revision: 57071 $

Abstract
--------

In this chapter we show how to use the **ZOPE Testbrowser** package
to perform **functional tests** for web services.


Blurb
-----

larg, blubb. Some **narkup** and ''another'' and ´a third´.

some preformatted::

    >>> 1 == 2
    True
    >>> type(1) is int


Links
-----

Plone_ is a CMS.

.. _Plone: http://plone.org


::

 vim: set ft=rst tw=75 nocin nosi ai sw=4 ts=4 expandtab:
